@@ -5,7 +5,7 @@
     Contact ........ jimmy@advcs.org
     Home Site ...... http://www.advcs.org/
     Program ........ Archive Mail
-    Version ........ 0.8
+    Version ........ 0.9
     Purpose ........ Allows you to download your email in a compressed archive
 
 *******************************************************************************/
@@ -45,14 +45,15 @@ class zipfile {
     } // end of the 'unix2DosTime()' method
 
     function addFile($data, $name, $time = 0) {
-        $name     = substr(str_replace('\\', '/', $name),0,100);
+        $name     = substr(str_replace('\\', '/', $name),0,98);
         if (!$time)
            $time = time();
         $time = decoct($time);
         $mode = "100666";
         $uid = "0";
         $gid = "0";
-        $len = decoct(strlen($data));
+        $x = strlen($data);
+        $len = decoct($x);
         $chk  = "\x20\x20\x20\x20\x20\x20\x20";
         $fr   = $this->pad($name,100);              // filename
         $fr  .= $this->tspace($this->pad($mode,8));       // Mode
@@ -65,12 +66,12 @@ class zipfile {
         $crc = decoct(checksum($fr . $chk . $fr2)) . "\x00 ";
         $fr = $this->pad($fr . $crc . $fr2,512);
         $x = strlen($data);
-        $y = 1;
-        while ($x > 512) {
-           $x = $x - 512;
-           $y++;
+        $y = intval($x/512)+1;
+        $x = ($y * 512) - $x;
+        if ($x == 512) {
+           $y--;
+           $x = 0;
         }
-        $x = 512 - $x;
         $fr .= $this->pad($data, $y * 512);
         $this -> datasec[] = $fr;
         unset($mode, $uid, $gid, $len, $chk);
@@ -80,7 +81,6 @@ class zipfile {
 
     function tspace($var,$space = 2, $char = "\x00") {
        return substr($var,0,strlen($var)-$space) . " " . $char;
-
     }
 
     function pads($var, $pad,$s = true) {
