@@ -5,7 +5,7 @@
     Contact ........ jimmy@advcs.org
     Home Site ...... http://www.advcs.org/
     Program ........ Archive Mail
-    Version ........ 0.8
+    Version ........ 0.9
     Purpose ........ Allows you to download your email in a compressed archive
 
 *******************************************************************************/
@@ -25,17 +25,21 @@
                   $timestamp = $msgs[$k]['TIME_STAMP'];
                   $date = date('m-j-Y', $timestamp);
                   if ($archiveattachments == 0) {
-                     $boundry = '';
+                     $boundry = array();
                      $cb = count($body_a);
                      for ($v = 0; $v < $cb; $v++) {
-                        if ($boundry != '') {
-                           if (trim($body_a[$v]) == $boundry) {
-                              if (!strpos($body_a[$v+1]," text/")) {
+                        if (count($boundry)) {
+                           if (in_array(trim($body_a[$v]), $boundry)) {
+                              if (!strpos($body_a[$v+1]," text/") && !strpos($body_a[$v+1]," multipart/alternative")) {
                                  $q = 1;
                                  $body_a[$v] = '';
                                  while ($v < $cb && $q) {
                                     $v++;
-                                    if (trim($body_a[$v]) == $eboundry)
+                                    if (in_array(trim($body_a[$v]), $boundry)) {
+                                       $q = 0;
+                                       $v--;
+                                    }
+                                    if (in_array(trim($body_a[$v]), $eboundry))
                                        $q = 0;
                                     if ($q != 0)
                                        unset($body_a[$v]);
@@ -43,9 +47,13 @@
                               }
                            }
                         }else{
-                           if (strpos($body_a[$v], 'boundary') !== false) {
-                              $boundry = "--" . substr(trim($body_a[$v]),10,strlen(trim($body_a[$v]))-11);
-                              $eboundry = $boundry . "--";
+                           if (strpos($body_a[$v], 'boundary="') !== false) {
+                              $x = strpos(strtolower($body_a[$v]),'boundary="')+10;
+                              if ($x == 11) $x = 10;
+                              $x2 = strpos($body_a[$v],'"',$x+1);
+                              $b = "--" . trim(substr(trim($body_a[$v]),$x,-1));
+                              $boundry[] = $b;
+                              $eboundry[] = $b . "--";
                            }
                         }
                      }
@@ -55,6 +63,9 @@
                   $body .= "\r\n";
                   $suffix = '.eml';
                   $name = archive_names ($archivefilenames, $email, $date, $c, $subject);
-                  $zipfile -> addFile($body, $name . $suffix);
+                  $max = $maxarray[$archivetype];
+                  if (strlen($name) > $max && $max > 0) $name = substr($name,0,$max);
+                  $increment = checkincrement(strtolower($name . $suffix));
+                  $zipfile -> addFile($body, $name . $increment .  $suffix, $timestamp);
                }
-?>
+?>
\ No newline at end of file
