@@ -63,7 +63,7 @@
                   }
                   array_shift($body_a);
                   $body = implode('', $body_a);
-                  srand();
+                  srand((double) microtime() * 1000000);
                   $filename = $timestamp . '.' . rand(1,100000) . '.' . 'localhost';
                   $dir = 'cur';
                   if (!$seen)
