@@ -5,7 +5,7 @@
     Contact ........ jimmy@advcs.org
     Home Site ...... http://www.advcs.org/
     Program ........ Archive Mail
-    Version ........ 0.8
+    Version ........ 0.9
     Purpose ........ Allows you to download your email in a compressed archive
 
 *******************************************************************************/
@@ -21,26 +21,28 @@
                   $email = $msgs[$k]['FROM'];
                   if (strpos($email, '<') !== false)
                      $email = substr($email, strpos($email, '<')+1, strpos($email, '>') - strpos($email, '<')-1);
-                  $email = trim($email);
-                  $email = str_replace(' ', '-', $email);
-                  $email = str_replace(chr(9), '-', $email);
+                  $email = trim(str_replace(array(' ',chr(9)), '-', $email));
                   $timestamp = $msgs[$k]['TIME_STAMP'];
                   if (date('d',$timestamp) < 10)
                      $mdate = date('D M  j H:i:s Y', $timestamp);
                   else
                      $mdate = date('D M d H:i:s Y', $timestamp);
                   if ($archiveattachments == 0) {
-                     $boundry = '';
+                     $boundry = array();
                      $cb = count($body_a);
                      for ($v = 0; $v < $cb; $v++) {
-                        if ($boundry != '') {
-                           if (trim($body_a[$v]) == $boundry) {
-                              if (!strpos($body_a[$v+1]," text/")) {
+                        if (count($boundry)) {
+                           if (in_array(trim($body_a[$v]), $boundry)) {
+                              if (!strpos($body_a[$v+1]," text/") && !strpos($body_a[$v+1]," multipart/alternative")) {
                                  $q = 1;
                                  $body_a[$v] = '';
                                  while ($v < $cb && $q) {
                                     $v++;
-                                    if (trim($body_a[$v]) == $eboundry)
+                                    if (in_array(trim($body_a[$v]), $boundry)) {
+                                       $q = 0;
+                                       $v--;
+                                    }
+                                    if (in_array(trim($body_a[$v]), $eboundry))
                                        $q = 0;
                                     if ($q != 0)
                                        unset($body_a[$v]);
@@ -48,9 +50,13 @@
                               }
                            }
                         }else{
-                           if (strpos($body_a[$v], 'boundary') !== false) {
-                              $boundry = "--" . substr(trim($body_a[$v]),10,strlen(trim($body_a[$v]))-11);
-                              $eboundry = $boundry . "--";
+                           if (strpos($body_a[$v], 'boundary="') !== false) {
+                              $x = strpos(strtolower($body_a[$v]),'boundary="')+10;
+                              if ($x == 11) $x = 10;
+                              $x2 = strpos($body_a[$v],'"',$x+1);
+                              $b = "--" . trim(substr(trim($body_a[$v]),$x,-1));
+                              $boundry[] = $b;
+                              $eboundry[] = $b . "--";
                            }
                         }
                      }
@@ -66,5 +72,4 @@
                   }
                   $mbox .= implode('', $body_a);
                }
-
 ?>
\ No newline at end of file
