@@ -5,7 +5,7 @@
     Contact ........ jimmy@advcs.org
     Home Site ...... http://www.advcs.org/
     Program ........ Archive Mail
-    Version ........ 0.8
+    Version ........ 0.9
     Purpose ........ Allows you to download your email in a compressed archive
 
 *******************************************************************************/
@@ -25,6 +25,7 @@
 //               $email2 = decodeHeader($message2->rfc822_header->getAddr_s('from'));
                $email = archive_replace_str($email2);
 //               $subject2 = decodeHeader($message2->rfc822_header->subject);
+               $timestamp = $msgs[$k]['TIME_STAMP'];
                $subject = archive_replace_str($subject2);
                if ($subject == '')
                   $subject = 'No Subject';
@@ -71,8 +72,9 @@
                            if ($archivefilenames < 1)
                               $archivefilenames = 0;
                         }
-                        $name = archive_names ($archivefilenames, $email, $date, $c, $subject);
-                        $increment = checkincrement($name . $suffix);
+                        $max = $maxarray[$archivetype];
+                        if (strlen($name) > $max && $max > 0) $name=substr($name,0,$max);
+                        $increment = checkincrement(strtolower($name . $suffix));
                         $filename = $name . $increment;
                      }
                      $filename = $filename . $suffix;
@@ -96,7 +98,7 @@
                      }
                   }
                   $body = $temp . $body;
-                  $zipfile -> addFile($body, $filename);
+                  $zipfile -> addFile($body, $filename,$timestamp);
                }
                if (!$seen)
                   sqimap_toggle_flag($imapConnection, $id, '\\Seen',false,true);
