@@ -12,26 +12,25 @@
 
       global $username, $data_dir;
       $filename = getHashedFile($username, $data_dir, "$username.pref");
-      $hashed_dir = GetHashedDir($username, $data_dir);
       $archivefilenames = getPref($filename, $username, 'archivefilenames');
       if ($archivefilenames == '') {
          $archivefilenames = 6;
-         setPref($hashed_dir, $username, 'archivefilenames', $archivefilenames);
+         setPref($data_dir, $username, 'archivefilenames', $archivefilenames);
       }
       $archiveattachments = getPref($filename, $username, 'archiveattachments');
       if ($archiveattachments == '') {
          $archiveattachments = 1;
-         setPref($hashed_dir, $username, 'archiveattachments', $archiveattachments);
+         setPref($data_dir, $username, 'archiveattachments', $archiveattachments);
       }
       $archivetype = getPref($filename, $username, 'archivetype');
       if ($archivetype == '') {
          $archivetype = 0;
-         setPref($hashed_dir, $username, 'archivetype', $archivetype);
+         setPref($data_dir, $username, 'archivetype', $archivetype);
       }
       $archiveent = getPref($filename, $username, 'archiveent');
       if ($archiveent == ''){
          $archiveent = 1;
-         setPref($hashed_dir, $username, 'archiveent', $archiveent);
+         setPref($data_dir, $username, 'archiveent', $archiveent);
       }
 
 ?>
\ No newline at end of file
